"""A sample Python package that I want to put onto PyPi."""
__version__ = "0.1.0"


def language():
    print("The language that I currently speak the best is called English.")


if __name__ == "__main__":

    # Test the things...
    language()
